/**
 * This file is part of the dcrypt project.
 *
 * Copyright: Copyright (C) dcrypt contributors 2008. All rights reserved.
 * License:   MIT
 * Authors:   Thomas Dixon
 */

module dcrypt.crypto.StreamCipher;

public import dcrypt.crypto.Cipher;
public import dcrypt.crypto.params.CipherParameters;
public import dcrypt.crypto.params.SymmetricKey;

/** Interface for a standard stream cipher. */
class StreamCipher : Cipher {   
    /**
     * Process one byte of input.
     *
     * Params:
     *     input = Byte to XOR with keystream.
     *
     * Returns: One byte of input XORed with the keystream.
     */
    abstract ubyte returnByte(ubyte input);
    
    /**
     * Process data from the input array
     * and place it into the output array.
     *
     * Params:
     *     input_  = Array containing input data.
     *     inOff   = Offset at where the data in input_ starts.
     *     len     = Length of input_ to process.
     *     output_ = Array which will hold the output data.
     *     outOff  = Offset at which to begin placing data in output_.
     *
     * Throws: dcrypt.crypto.errors.NotInitializedError if cipher
     *         was not initialized.
     */
    abstract void processBytes(void[] input_, uint inOff, 
                                   uint len, void[] output_, uint outOff);
}
